==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNetworkDestinationIpv6Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersNetworkDestinationIpv6Args(
    public val cidr: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args =
        com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args.builder()
            .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNetworkDestinationIpv6Args].
 */
@PulumiTagMarker
public class InsightFiltersNetworkDestinationIpv6ArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("klfmwebmdmqwapxp")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("cmnmeyfcnrsxkoyf")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersNetworkDestinationIpv6Args =
        InsightFiltersNetworkDestinationIpv6Args(
            cidr = cidr ?: throw PulumiNullFieldException("cidr"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersNetworkDestinationIpv6Args.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property cidr A finding's CIDR value.
 */
public data class InsightFiltersNetworkDestinationIpv6Args(
    public val cidr: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args = com.pulumi.aws.securityhub.inputs.InsightFiltersNetworkDestinationIpv6Args.builder()
        .cidr(cidr.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersNetworkDestinationIpv6Args].
 */
@PulumiTagMarker
public class InsightFiltersNetworkDestinationIpv6ArgsBuilder internal constructor() {
    private var cidr: Output<String>? = null

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("mpfahytnbgwlhqsp")
    public suspend fun cidr(`value`: Output<String>) {
        this.cidr = value
    }

    /**
     * @param value A finding's CIDR value.
     */
    @JvmName("ayftntjspvmivipg")
    public suspend fun cidr(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cidr = mapped
    }

    internal fun build(): InsightFiltersNetworkDestinationIpv6Args =
        InsightFiltersNetworkDestinationIpv6Args(
            cidr = cidr ?: throw PulumiNullFieldException("cidr"),
        )
}
